searchNodes=[{"doc":"Client-driven interactive widgets for Livebook. Kino is the library used by Livebook to render rich and interactive output directly from your Elixir code. Kino renders any data structure that implements the Kino.Render protocol, falling back to the inspect/2 representation whenever an implementation is not available. The data structures supported by Kino out of the box are: VegaLite VegaLite specifications are rendered as visualizations: Vl . new ( ... ) |&gt; Vl . data_from_series ( ... ) |&gt; ... Kino.VegaLite Kino.VegaLite is an extension of VegaLite that allows data to be streamed: widget = Vl . new ( ... ) |&gt; Vl . data_from_series ( ... ) |&gt; ... |&gt; Kino.VegaLite . new ( ) |&gt; Kino . render ( ) Kino.VegaLite . push ( widget , %{ x : 1 , y : 2 } ) Kino.ETS Kino.ETS implements a data table output for ETS tables in the system: tid = :ets . new ( :users , [ :set , :public ] ) Kino.ETS . new ( tid ) Kino.DataTable Kino.DataTable implements a data table output for user-provided tabular data: data = [ %{ id : 1 , name : &quot;Elixir&quot; , website : &quot;https://elixir-lang.org&quot; } , %{ id : 2 , name : &quot;Erlang&quot; , website : &quot;https://www.erlang.org&quot; } ] Kino.DataTable . new ( data ) Kino.Image Kino.Image wraps binary image content and can be used to render raw images of any given format: content = File . read! ( &quot;/path/to/image.jpeg&quot; ) Kino.Image . new ( content , &quot;image/jpeg&quot; ) Kino.Markdown Kino.Markdown wraps Markdown content for richer text rendering. Kino.Markdown . new ( &quot;&quot;&quot; # Example A regular Markdown file. ## Code ```elixir &quot;Elixir&quot; |&gt; String.graphemes() |&gt; Enum.frequencies() ``` ## Table | ID | Name | Website | | -- | ------ | ----------------------- | | 1 | Elixir | https://elixir-lang.org | | 2 | Erlang | https://www.erlang.org | &quot;&quot;&quot; ) Kino.Ecto Kino.Ecto implements a data table output for arbitrary Ecto queries: Kino.Ecto . new ( Weather , Repo ) Kino.Frame Kino.Frame is a placeholder for static outptus that can be dynamically updated. widget = Kino.Frame . new ( ) |&gt; Kino . render ( ) for i &lt;- 1 .. 100 do Kino.Frame . render ( widget , i ) Process . sleep ( 50 ) end Also see Kino.animate/3 . User interactions Kino.Input and Kino.Control provide a set of widgets for entering data and capturing user events. See the respective module documentation for examples. All others All other data structures are rendered as text using Elixir's inspect/2 .","ref":"Kino.html","title":"Kino","type":"module"},{"doc":"Returns a widget that periodically calls the given function to render a new result. The callback is run every interval_ms milliseconds and receives the accumulated value. The callback should return either of: {:cont, term_to_render, acc} - the continue :halt - to no longer schedule callback evaluation This function uses Kino.Frame as the underlying widget. Examples # Render new Markdown every 100ms Kino . animate ( 100 , 0 , fn i -&gt; md = Kino.Markdown . new ( &quot;**Iteration: ` \#{ i } `**&quot; ) { :cont , md , i + 1 } end )","ref":"Kino.html#animate/3","title":"Kino.animate/3","type":"function"},{"doc":"Configures Kino. The supported options are: :inspect They are discussed individually in the sections below. Inspect A keyword list containing inspect options used for printing usual evaluation results. Defaults to pretty formatting with a limit of 50 entries. To show more entries, you configure a higher limit: Kino . configure ( inspect : [ limit : 200 ] ) You can also show all entries by setting the limit to :infinity , but keep in mind that for large data structures it is memory-expensive and is not an advised configuration in this case. Instead prefer the use of IO.inspect/2 with :infinity limit when needed. See Inspect.Opts for the full list of options.","ref":"Kino.html#configure/1","title":"Kino.configure/1","type":"function"},{"doc":"Inspects the given term as cell output. This works essentially the same as IO.inspect/2 , except it always produces colored text and respects the configuration set with configure/1 . Opposite to render/1 , it does not attempt to render the given term as a widget.","ref":"Kino.html#inspect/2","title":"Kino.inspect/2","type":"function"},{"doc":"Returns a special value that results in no visible output.","ref":"Kino.html#nothing/0","title":"Kino.nothing/0","type":"function"},{"doc":"Renders the given term as cell output. This effectively allows any Livebook cell to have multiple evaluation results.","ref":"Kino.html#render/1","title":"Kino.render/1","type":"function"},{"doc":"Starts a process under the Kino supervisor. The process is automatically terminated when the current process terminates or the current cell reevaluates.","ref":"Kino.html#start_child/1","title":"Kino.start_child/1","type":"function"},{"doc":"","ref":"Kino.html#t:nothing/0","title":"Kino.nothing/0","type":"type"},{"doc":"Various widgets for user interactions. Each widget is a UI control element that the user interacts with, consequenty producing an event stream. Those widgets are often useful paired with Kino.Frame for presenting content that changes upon user interactions. Examples First, create a control and make sure it is rendered, either by placing it at the end of a code cell or by explicitly rendering it with Kino.render/1 . button = Kino.Control . button ( &quot;Hello&quot; ) Next, to receive events from the control, a process needs to subscribe to it and specify pick a name to distinguish the events. Kino.Control . subscribe ( button , :hello ) As the user interacts with the button, the subscribed process receives corresponding events. IEx.Helpers . flush ( ) #=&gt; {:hello, %{origin: #PID&lt;10895.9854.0&gt;}} #=&gt; {:hello, %{origin: #PID&lt;10895.9854.0&gt;}}","ref":"Kino.Control.html","title":"Kino.Control","type":"module"},{"doc":"Creates a new button.","ref":"Kino.Control.html#button/1","title":"Kino.Control.button/1","type":"function"},{"doc":"Creates a new keyboard control. This widget is represented as button that toggles interception mode, in which the given keyboard events are captured. Event info In addition to standard properties, all events include additional properties. Key events :type - either :keyup or :keydown :key - the value matching the browser KeyboardEvent.key Status event :type - either :status :enabled - whether the keyboard is activated Examples Create the widget: keyboard = Kino.Control . keyboard ( [ :keyup , :keydown ] ) Subscribe to events: Kino.Control . subscribe ( keyboard , :keyboard ) As the user types events are streamed: IEx.Helpers . flush ( ) #=&gt; {:keyboard, %{key: &quot;o&quot;, origin: #PID&lt;10895.9854.0&gt;, type: :keydown}} #=&gt; {:keyboard, %{key: &quot;k&quot;, origin: #PID&lt;10895.9854.0&gt;, type: :keydown}} #=&gt; {:keyboard, %{key: &quot;o&quot;, origin: #PID&lt;10895.9854.0&gt;, type: :keyup}} #=&gt; {:keyboard, %{key: &quot;k&quot;, origin: #PID&lt;10895.9854.0&gt;, type: :keyup}}","ref":"Kino.Control.html#keyboard/1","title":"Kino.Control.keyboard/1","type":"function"},{"doc":"Subscribes the calling process to control events. The events are sent as {tag, info} , where info is a map with event details. In particular, it always includes :origin , which is an opaque identifier of the client that triggered the event.","ref":"Kino.Control.html#subscribe/2","title":"Kino.Control.subscribe/2","type":"function"},{"doc":"Unsubscribes the calling process from control events.","ref":"Kino.Control.html#unsubscribe/1","title":"Kino.Control.unsubscribe/1","type":"function"},{"doc":"","ref":"Kino.Control.html#t:t/0","title":"Kino.Control.t/0","type":"type"},{"doc":"A widget for interactively viewing enumerable data. The data must be an enumerable of records, where each record is either map, struct, keyword list or tuple. Examples data = [ %{ id : 1 , name : &quot;Elixir&quot; , website : &quot;https://elixir-lang.org&quot; } , %{ id : 2 , name : &quot;Erlang&quot; , website : &quot;https://www.erlang.org&quot; } ] Kino.DataTable . new ( data ) The tabular view allows you to quickly preview the data and analyze it thanks to sorting capabilities. data = Process . list ( ) |&gt; Enum . map ( &amp; Process . info / 1 ) Kino.DataTable . new ( data , keys : [ :registered_name , :initial_call , :reductions , :stack_size ] )","ref":"Kino.DataTable.html","title":"Kino.DataTable","type":"module"},{"doc":"Starts a widget process with enumerable tabular data. Options :keys - a list of keys to include in the table for each record. The order is reflected in the rendered table. For tuples use 0-based indices. Optional. :sorting_enabled - whether the widget should support sorting the data. Sorting requires traversal of the whole enumerable, so it may not be desirable for lazy enumerables. Defaults to true if data is a list and false otherwise. :show_underscored - whether to include record keys starting with underscore. This option is ignored if :keys is also given. Defaults to false .","ref":"Kino.DataTable.html#new/2","title":"Kino.DataTable.new/2","type":"function"},{"doc":"","ref":"Kino.DataTable.html#start/2","title":"Kino.DataTable.start/2","type":"function"},{"doc":"","ref":"Kino.DataTable.html#t:t/0","title":"Kino.DataTable.t/0","type":"type"},{"doc":"A widget for interactively viewing an ETS table. Examples tid = :ets . new ( :users , [ :set , :public ] ) Kino.ETS . new ( tid ) Kino.ETS . new ( :elixir_config )","ref":"Kino.ETS.html","title":"Kino.ETS","type":"module"},{"doc":"Starts a widget process representing the given ETS table. Note that private tables cannot be read by an arbitrary process, so the given table must have either public or protected access.","ref":"Kino.ETS.html#new/1","title":"Kino.ETS.new/1","type":"function"},{"doc":"","ref":"Kino.ETS.html#start/1","title":"Kino.ETS.start/1","type":"function"},{"doc":"","ref":"Kino.ETS.html#t:t/0","title":"Kino.ETS.t/0","type":"type"},{"doc":"A widget for interactively viewing Ecto query results. The data must be an enumerable of records, where each record is either map, struct, keyword list or tuple. Examples The widget primarly allows for viewing a database table given a schema: Kino.Ecto . new ( Weather , Repo ) However, the first argument can be any queryable, so you can pipe arbitrary queries directly to the widget: from ( w in Weather , where : w . city == &quot;New York&quot; ) |&gt; Kino.Ecto . new ( Repo )","ref":"Kino.Ecto.html","title":"Kino.Ecto","type":"module"},{"doc":"Starts a widget process with the given queryable as the data source.","ref":"Kino.Ecto.html#new/2","title":"Kino.Ecto.new/2","type":"function"},{"doc":"","ref":"Kino.Ecto.html#t:t/0","title":"Kino.Ecto.t/0","type":"type"},{"doc":"A widget wrapping a static output. This widget serves as a placeholder for a regular output, so that it can be dynamically replaced at any time. Also see Kino.animate/3 which offers a convenience on top of this widget. Examples widget = Kino.Frame . new ( ) |&gt; Kino . render ( ) for i &lt;- 1 .. 100 do Kino.Frame . render ( widget , i ) Process . sleep ( 50 ) end Or with a scheduled task in the background. widget = Kino.Frame . new ( ) |&gt; Kino . render ( ) Kino.Frame . periodically ( widget , 50 , 0 , fn i -&gt; Kino.Frame . render ( widget , i ) { :cont , i + 1 } end )","ref":"Kino.Frame.html","title":"Kino.Frame","type":"module"},{"doc":"Starts a widget process.","ref":"Kino.Frame.html#new/0","title":"Kino.Frame.new/0","type":"function"},{"doc":"Registers a callback to run periodically in the widget process. The callback is run every interval_ms milliseconds and receives the accumulated value. The callback should return either of: {:cont, acc} - the continue with the new accumulated value :halt - to no longer schedule callback evaluation The callback is run for the first time immediately upon registration.","ref":"Kino.Frame.html#periodically/4","title":"Kino.Frame.periodically/4","type":"function"},{"doc":"Renders the given term within the frame. This works similarly to Kino.render/1 , but the frame widget only shows the last rendered result.","ref":"Kino.Frame.html#render/2","title":"Kino.Frame.render/2","type":"function"},{"doc":"","ref":"Kino.Frame.html#t:t/0","title":"Kino.Frame.t/0","type":"type"},{"doc":"A struct wrapping a binary image. This is just a meta-struct that implements the Kino.Render protocol, so that it gets rendered as the underlying image. Examples content = File . read! ( &quot;/path/to/image.jpeg&quot; ) Kino.Image . new ( content , &quot;image/jpeg&quot; )","ref":"Kino.Image.html","title":"Kino.Image","type":"module"},{"doc":"Wraps the given binary content into the image struct. The given type be either :jpeg , :png , :gif , :svg or a string with image MIME type.","ref":"Kino.Image.html#new/2","title":"Kino.Image.new/2","type":"function"},{"doc":"","ref":"Kino.Image.html#t:common_image_type/0","title":"Kino.Image.common_image_type/0","type":"type"},{"doc":"","ref":"Kino.Image.html#t:mime_type/0","title":"Kino.Image.mime_type/0","type":"type"},{"doc":"","ref":"Kino.Image.html#t:t/0","title":"Kino.Image.t/0","type":"type"},{"doc":"Various input elements for entering data. Examples First, create an input and make sure it is rendered, either by placing it at the end of a code cell or by explicitly rendering it with Kino.render/1 . input = Kino.Input . text ( &quot;Name&quot; ) Then read the value at any later point: name = Kino.Input . read ( input )","ref":"Kino.Input.html","title":"Kino.Input","type":"module"},{"doc":"Creates a new checkbox. The input value can be either true or false . Options :default - the initial input value. Defaults to false","ref":"Kino.Input.html#checkbox/2","title":"Kino.Input.checkbox/2","type":"function"},{"doc":"Creates a new color input. The input value can be a hex color string. Options :default - the initial input value. Defaults to #6583FF","ref":"Kino.Input.html#color/2","title":"Kino.Input.color/2","type":"function"},{"doc":"Creates a new number input. The input value is can be either a number or nil . Options :default - the initial input value. Defaults to nil","ref":"Kino.Input.html#number/2","title":"Kino.Input.number/2","type":"function"},{"doc":"Creates a new password input. This is similar to text input, except the content is not visible by default. Options :default - the initial input value. Defaults to &quot;&quot;","ref":"Kino.Input.html#password/2","title":"Kino.Input.password/2","type":"function"},{"doc":"Creates a new slider input. The input value can be either float in the configured range. Options :default - the initial input value. Defaults to the minimum value :min - the minimum value :max - the maximum value :step - the slider increment","ref":"Kino.Input.html#range/2","title":"Kino.Input.range/2","type":"function"},{"doc":"Synchronously reads the current input value. Note that to retrieve the value, the input must be rendered first, otherwise an error is raised. Examples input = Kino.Input . text ( &quot;Name&quot; ) Kino.Input . read ( input )","ref":"Kino.Input.html#read/1","title":"Kino.Input.read/1","type":"function"},{"doc":"Creates a new select input. The input expects a list of options in the form [{value, label}] , where value is an arbitrary term and label is a descriptive string. Options :default - the initial input value. Defaults to the first value from the given list of options Examples Kino.Input . select ( &quot;Language&quot; , [ en : &quot;English&quot; , fr : &quot;Français&quot; ] ) Kino.Input . select ( &quot;Language&quot; , [ { 1 , &quot;One&quot; } , { 2 , &quot;Two&quot; } , { 3 , &quot;Three&quot; } ] )","ref":"Kino.Input.html#select/3","title":"Kino.Input.select/3","type":"function"},{"doc":"Subscribes the calling process to input changes. The events are sent as {tag, info} . See Kino.Control.subscribe/2 for more details.","ref":"Kino.Input.html#subscribe/2","title":"Kino.Input.subscribe/2","type":"function"},{"doc":"Creates a new text input. Options :default - the initial input value. Defaults to &quot;&quot;","ref":"Kino.Input.html#text/2","title":"Kino.Input.text/2","type":"function"},{"doc":"Creates a new multiline text input. Options :default - the initial input value. Defaults to &quot;&quot;","ref":"Kino.Input.html#textarea/2","title":"Kino.Input.textarea/2","type":"function"},{"doc":"Unsubscribes the calling process from input events.","ref":"Kino.Input.html#unsubscribe/1","title":"Kino.Input.unsubscribe/1","type":"function"},{"doc":"Creates a new URL input. The input value can be either a valid URL string or nil . Options :default - the initial input value. Defaults to nil","ref":"Kino.Input.html#url/2","title":"Kino.Input.url/2","type":"function"},{"doc":"","ref":"Kino.Input.html#t:t/0","title":"Kino.Input.t/0","type":"type"},{"doc":"A struct wrapping a Markdown content. This is just a meta-struct that implements the Kino.Render protocol, so that it gets rendered as markdown. Examples Kino.Markdown . new ( &quot;&quot;&quot; # Example A regular Markdown file. ## Code ```elixir &quot;Elixir&quot; |&gt; String.graphemes() |&gt; Enum.frequencies() ``` ## Table | ID | Name | Website | | -- | ------ | ----------------------- | | 1 | Elixir | https://elixir-lang.org | | 2 | Erlang | https://www.erlang.org | &quot;&quot;&quot; ) This format may come in handy when exploring Markdown from external sources: content = File . read! ( &quot;/path/to/README.md&quot; ) Kino.Markdown . new ( content )","ref":"Kino.Markdown.html","title":"Kino.Markdown","type":"module"},{"doc":"Wraps the given binary content into the markdown struct.","ref":"Kino.Markdown.html#new/1","title":"Kino.Markdown.new/1","type":"function"},{"doc":"","ref":"Kino.Markdown.html#t:t/0","title":"Kino.Markdown.t/0","type":"type"},{"doc":"A number of output formats supported by Livebook.","ref":"Kino.Output.html","title":"Kino.Output","type":"module"},{"doc":"See control/0 .","ref":"Kino.Output.html#control/1","title":"Kino.Output.control/1","type":"function"},{"doc":"See frame_dynamic/0 .","ref":"Kino.Output.html#frame_dynamic/1","title":"Kino.Output.frame_dynamic/1","type":"function"},{"doc":"See image/0 .","ref":"Kino.Output.html#image/2","title":"Kino.Output.image/2","type":"function"},{"doc":"See input/0 .","ref":"Kino.Output.html#input/1","title":"Kino.Output.input/1","type":"function"},{"doc":"Returns text_block/0 with the inspected term.","ref":"Kino.Output.html#inspect/2","title":"Kino.Output.inspect/2","type":"function"},{"doc":"See markdown/0 .","ref":"Kino.Output.html#markdown/1","title":"Kino.Output.markdown/1","type":"function"},{"doc":"See table_dynamic/0 .","ref":"Kino.Output.html#table_dynamic/1","title":"Kino.Output.table_dynamic/1","type":"function"},{"doc":"See text_block/0 .","ref":"Kino.Output.html#text_block/1","title":"Kino.Output.text_block/1","type":"function"},{"doc":"See text_inline/0 .","ref":"Kino.Output.html#text_inline/1","title":"Kino.Output.text_inline/1","type":"function"},{"doc":"See vega_lite_dynamic/0 .","ref":"Kino.Output.html#vega_lite_dynamic/1","title":"Kino.Output.vega_lite_dynamic/1","type":"function"},{"doc":"See vega_lite_static/0 .","ref":"Kino.Output.html#vega_lite_static/1","title":"Kino.Output.vega_lite_static/1","type":"function"},{"doc":"A control widget. All controls have the following properties: :type - one of the recognised control types :ref - a unique identifier :destination - the process to send event messages to On top of that, each control type may have additional attributes. Events All control events are sent to :destination as {:event, id, info} , where info is a map including additional details. In particular, it always includes :origin , which is an opaque identifier of the client that triggered the event.","ref":"Kino.Output.html#t:control/0","title":"Kino.Output.control/0","type":"type"},{"doc":"","ref":"Kino.Output.html#t:control_attrs/0","title":"Kino.Output.control_attrs/0","type":"type"},{"doc":"","ref":"Kino.Output.html#t:control_ref/0","title":"Kino.Output.control_ref/0","type":"type"},{"doc":"Animable output. This output points to a server process that clients can talk to. Communication protocol A client process should connect to the server process by sending: { :connect , pid ( ) } And expect the following reply: { :connect_reply , %{ output : Kino.Output . t ( ) | nil } } The server process may then keep sending one of the following events: { :render , %{ output : Kino.Output . t ( ) } }","ref":"Kino.Output.html#t:frame_dynamic/0","title":"Kino.Output.frame_dynamic/0","type":"type"},{"doc":"An empty output that should be ignored whenever encountered.","ref":"Kino.Output.html#t:ignored/0","title":"Kino.Output.ignored/0","type":"type"},{"doc":"A raw image in the given format.","ref":"Kino.Output.html#t:image/0","title":"Kino.Output.image/0","type":"type"},{"doc":"An input field. All inputs have the following properties: :type - one of the recognised input types :ref - a unique identifier :id - a persistent input identifier, the same on every reevaluation :label - an arbitrary text used as the input caption :default - the initial input value :destination - the process to send event messages to On top of that, each input type may have additional attributes.","ref":"Kino.Output.html#t:input/0","title":"Kino.Output.input/0","type":"type"},{"doc":"","ref":"Kino.Output.html#t:input_attrs/0","title":"Kino.Output.input_attrs/0","type":"type"},{"doc":"","ref":"Kino.Output.html#t:input_id/0","title":"Kino.Output.input_id/0","type":"type"},{"doc":"","ref":"Kino.Output.html#t:input_ref/0","title":"Kino.Output.input_ref/0","type":"type"},{"doc":"Markdown content.","ref":"Kino.Output.html#t:markdown/0","title":"Kino.Output.markdown/0","type":"type"},{"doc":"Livebook cell output may be one of these values and gets rendered accordingly.","ref":"Kino.Output.html#t:t/0","title":"Kino.Output.t/0","type":"type"},{"doc":"Interactive data table. This output points to a server process that serves data requests, handling filtering, sorting and slicing data as necessary. Communication protocol A client process should connect to the server process by sending: { :connect , pid ( ) } And expect the following reply: @type column :: %{ key : term ( ) , label : binary ( ) } { :connect_reply , %{ name : binary ( ) , columns : list ( column ( ) ) , features : list ( :refetch | :pagination | :sorting ) } } The client may then query for table rows by sending the following requests: @type rows_spec :: %{ offset : non_neg_integer ( ) , limit : pos_integer ( ) , order_by : nil | term ( ) , order : :asc | :desc , } { :get_rows , pid ( ) , rows_spec ( ) } To which the server responds with retrieved data: @type row :: %{ # An identifier, opaque to the client ref : term ( ) , # A string value for every column key fields : list ( %{ term ( ) =&gt; binary ( ) } ) } { :rows , %{ rows : list ( row ( ) ) , total_rows : non_neg_integer ( ) , # Possibly an updated columns specification columns : :initial | list ( column ( ) ) } }","ref":"Kino.Output.html#t:table_dynamic/0","title":"Kino.Output.table_dynamic/0","type":"type"},{"doc":"Standalone text block.","ref":"Kino.Output.html#t:text_block/0","title":"Kino.Output.text_block/0","type":"type"},{"doc":"Regular text, adjacent such outputs can be treated as a whole.","ref":"Kino.Output.html#t:text_inline/0","title":"Kino.Output.text_inline/0","type":"type"},{"doc":"Interactive Vega-Lite graphic with data streaming capabilities. This output points to a server process that clients can talk to. Communication protocol A client process should connect to the server process by sending: { :connect , pid ( ) } And expect the following reply: { :connect_reply , %{ spec : map ( ) } } The server process may then keep sending one of the following events: { :push , %{ data : list ( ) , dataset : binary ( ) , window : non_neg_integer ( ) } }","ref":"Kino.Output.html#t:vega_lite_dynamic/0","title":"Kino.Output.vega_lite_dynamic/0","type":"type"},{"doc":"Vega-Lite graphic. spec should be a valid Vega-Lite specification, essentially JSON represented with Elixir data structures.","ref":"Kino.Output.html#t:vega_lite_static/0","title":"Kino.Output.vega_lite_static/0","type":"type"},{"doc":"Protocol defining term formatting in the context of Livebook.","ref":"Kino.Render.html","title":"Kino.Render","type":"protocol"},{"doc":"Transforms the given value into a Livebook-compatible output.","ref":"Kino.Render.html#to_livebook/1","title":"Kino.Render.to_livebook/1","type":"function"},{"doc":"","ref":"Kino.Render.html#t:t/0","title":"Kino.Render.t/0","type":"type"},{"doc":"A widget wrapping VegaLite graphic. This widget allow for rendering regular VegaLite graphic and then streaming new data points to update the graphic. Examples widget = Vl . new ( width : 400 , height : 400 ) |&gt; Vl . mark ( :line ) |&gt; Vl . encode_field ( :x , &quot;x&quot; , type : :quantitative ) |&gt; Vl . encode_field ( :y , &quot;y&quot; , type : :quantitative ) |&gt; Kino.VegaLite . new ( ) |&gt; Kino . render ( ) for i &lt;- 1 .. 300 do point = %{ x : i / 10 , y : :math . sin ( i / 10 ) } Kino.VegaLite . push ( widget , point ) Process . sleep ( 25 ) end","ref":"Kino.VegaLite.html","title":"Kino.VegaLite","type":"module"},{"doc":"Removes all data points from the graphic dataset. Options dataset - name of the targetted dataset from the VegaLite specification. Defaults to the default anonymous dataset.","ref":"Kino.VegaLite.html#clear/2","title":"Kino.VegaLite.clear/2","type":"function"},{"doc":"Starts a widget process with the given VegaLite definition.","ref":"Kino.VegaLite.html#new/1","title":"Kino.VegaLite.new/1","type":"function"},{"doc":"Registers a callback to run periodically in the widget process. The callback is run every interval_ms milliseconds and receives the accumulated value. The callback should return either of: {:cont, acc} - the continue with the new accumulated value :halt - to no longer schedule callback evaluation The callback is run for the first time immediately upon registration.","ref":"Kino.VegaLite.html#periodically/4","title":"Kino.VegaLite.periodically/4","type":"function"},{"doc":"Appends a single data point to the graphic dataset. Options :window - the maximum number of data points to keep. This option is useful when you are appending new data points to the plot over a long period of time. dataset - name of the targetted dataset from the VegaLite specification. Defaults to the default anonymous dataset.","ref":"Kino.VegaLite.html#push/3","title":"Kino.VegaLite.push/3","type":"function"},{"doc":"Appends a number of data points to the graphic dataset. See push/3 for more details.","ref":"Kino.VegaLite.html#push_many/3","title":"Kino.VegaLite.push_many/3","type":"function"},{"doc":"","ref":"Kino.VegaLite.html#start/1","title":"Kino.VegaLite.start/1","type":"function"},{"doc":"","ref":"Kino.VegaLite.html#t:t/0","title":"Kino.VegaLite.t/0","type":"type"}]